@@ -8,12 +8,10 @@ import logging
 import time
 import zipfile
 
-
 from pathlib import Path
 from colorama import init, Fore, Back
 from tqdm import tqdm
 
-
 import browser_cookie3
 import requests
 import webbrowser
@@ -335,7 +333,6 @@ def generate_download_list(rdata, runlevel):
 
 
 def download_file(ccmfile, tf, td, config, headers=None, cookies=None):
-
     # download and extract files
     # todo: extract tar, rar, ...
     try:
@@ -371,46 +368,61 @@ def download_file(ccmfile, tf, td, config, headers=None, cookies=None):
 
 
 def download_files(tf, config, downloads, target_folder, metadata):
-
     def cli_escape():
         """
-        # opens firefox and the ccmixter website, which is needed to
-        # get and set cookies and stuff, needed to be allowed to download files
-        todo: check / ask for browser to use..
-        :return:
+        # opens a new browser tab and the ccmixter website, which is needed to
+        # get and set cookies and stuff, to be allowed to download files
+
+        https://github.com/fake-useragent/fake-useragent
+
+        https://github.com/borisbabic/browser_cookie3
+
+        https://docs.python.org/3/library/webbrowser.html
+
         """
-        user_help = """
-            ##########################################
-            You NEED Firefox set as your default webbrowser!
-            Dont close the freshly spawning firefox window  
-            until all downloads are finished. 
-            
-            ##########################################\n
-                                """
-        timer = 15
-        while timer > 0:
-            time.sleep(1)
-            timer -= 1
-            logging.info('Waiting for {} seconds'.format(timer))
 
-        webbrowser.open('http://ccmixter.org')
+        response = None
+        while response not in {"chrome", "firefox", "safari"}:
+            response = input("Please enter chrome or firefox or safari: ")
+            try:
+                # browser selection
+                ua = UserAgent()
+                if response == 'chrome':
+                    webbrowser.get(using='chrome').open('http://ccmixter.org', new=2)
+                    cookies = browser_cookie3.chrome(domain_name='ccmixter.org')
+                    headers = {
+                        "User-Agent": ua.chrome,
+                        # to be set later: "Referer": ccmfile['download_url'],
+                        "Host": "ccmixter.org"
+                    }
+                elif response == 'safari':
+                    webbrowser.get(using='safari').open('http://ccmixter.org', new=2)
+                    cookies = browser_cookie3.safari(domain_name='ccmixter.org')
+                    headers = {
+                        "User-Agent": ua.safari,
+                        # to be set later: "Referer": ccmfile['download_url'],
+                        "Host": "ccmixter.org"
+                    }
+                else:
+                    webbrowser.get(using='firefox').open('http://ccmixter.org', new=2)
+                    cookies = browser_cookie3.firefox(domain_name='ccmixter.org')
+                    headers = {
+                        "User-Agent": ua.firefox,
+                        # to be set later: "Referer": ccmfile['download_url'],
+                        "Host": "ccmixter.org"
+                    }
 
-        timer = 15
-        while timer > 0:
-            time.sleep(1)
-            timer -= 1
-            logging.info('Waiting for {} seconds'.format(timer))
+                timer = 15
+                while timer > 0:
+                    time.sleep(1)
+                    timer -= 1
+                    logging.info('Waiting for {} seconds'.format(timer))
 
-        cookies = browser_cookie3.firefox(domain_name='ccmixter.org')
+            except Exception as err:
+                logging.error(f'{err}')
+                cookies, headers = None, None
 
-        ua = UserAgent()
-        headers = {
-            "User-Agent": ua.firefox,
-            # to be set later: "Referer": ccmfile['download_url'],
-            "Host": "ccmixter.org"
-        }
-
-        return cookies, headers
+            return cookies, headers
 
     cookies, headers = cli_escape()
 
