@@ -4,34 +4,47 @@ import logging
 
 from pyccmc.api import *
 
-info = """
-#######################################################################
-# ccmclient
-# creates a local copy of audio files from given artist name or query
-# and stores the downloads info 
-# api documentation: http://ccmixter.org/query-api
-# client documentation:  https://dev.azure.com/kreaterra/_git/ktccmclient
-#######################################################################
-"""
-print(info)
+print(
+    "Download and Extract Ccmixter Artists uploads and work with the metadata. "
+    "Api documentation: http://ccmixter.org/query-api")
 
 # script info
 __author__ = 'tigabeatz'
 __contact__ = 'https://dev.azure.com/kreaterra/_git/ccmclient'
 __license__ = 'gpl-3.0'
-__version__ = '0.0.2'
+__version__ = '0.0.3'
+
+PROGRAM_HELP = """
+###########################################################
+- just type a username (secret mixter mode)
+
+OR
+
+- type itq to start interactive query mode
+- type mdm to generate metadata list for downloaded files
+- type graph to vizualize the network of uploads and remixes 
+  centering on the users uploads
+
+###########################################################\n
+your selection:"""
 
 
 def add_args():
     # command line arguments
     parser = argparse.ArgumentParser()
-    parser.add_argument("--test", help="check if this tool is working", default=False)
-    parser.add_argument("--artist", help="an artists name")
-    parser.add_argument("--limit", help="maximum allowed results", default=10)
-    parser.add_argument("--dryrun", default=False)
-    parser.add_argument("--itq", default=False)
-    parser.add_argument("--mdm", default=False)
-    parser.add_argument("--graph", default=False)
+    parser.add_argument("--test", help="Check if this tool is working",
+                        default=False)
+    parser.add_argument("--artist", help="An Ccmixter artist name")
+    parser.add_argument("--limit", help="Maximum allowed results",
+                        default=10)
+    parser.add_argument("--dryrun", help="Do not download data files",
+                        default=False)
+    parser.add_argument("--itq", help="Interactive query api parameters",
+                        default=False)
+    parser.add_argument("--mdm", help="manage metadata",
+                        default=False)
+    parser.add_argument("--graph", help="prepare for graph display",
+                        default=False)
     parser.add_argument("--proxy", help="http(s):\\url:port")
     parser.add_argument("--query", help="json with cc mixter api parameters {user:tigabeatz;limit:1}")
     parser.add_argument("--folder", help=" where to store your requests data, defaults to ccmclient folder",
@@ -142,21 +155,7 @@ def main():
         # get user input if not set by parameters
         elif (not args.artist) and (not args.query) and (not args.itq) and (not args.mdm):
 
-            user_help = """
-    ##########################################
-    - just type a username (secret mixter mode)
-     
-    OR
-      
-    - type itq to start interactive query mode
-    - type mdm to generate metadata list for downloaded files
-    - type graph to vizualize the network of uploads and 
-      remixes centering on the users uploads
-    
-    ##########################################\n
-    your selection:
-                        """
-            uin = input(user_help)
+            uin = input(PROGRAM_HELP)
             print(uin)
 
             if uin == 'itq':
@@ -217,8 +216,6 @@ def main():
         try:
             logging.debug('creating downloads')
 
-            logging.debug('the return is: ' + str(r))
-
             # generate a list of downloadable files
             downloads = generate_download_list(r, config['local']['dryrun'])
 
